import grpc
from google.protobuf.json_format import ParseDict
from mesh_rpc.mesh import MeshRPC
from mesh_rpc.exp import MeshRPCException

from .lib.atc_pb2 import FeedMessage
from .defaults import Default

class MeshATC(MeshRPC):
    def __init__(self, endpoint='127.0.0.1:5555'):
        super().__init__(endpoint)

    def subscribe(self, geospace):
        s = super().subscribe(Default.channel, geospace)

        feed = FeedMessage()

        channelLen = len(Default.channel)

        try:
            for msg in s:
                feed.ParseFromString(msg.raw)
                yield feed, msg.topic.pop()[channelLen:]
        except grpc.RpcError as e:
            raise MeshRPCException(e.details())

    def unsubscribe(self, geospaces):
        return super().unsubscribe(Default.channel, geospaces)
    
    def registerToPublish(self, geospace):
        try:
            super().registerToPublish(Default.channel, geospace)
        except MeshRPCException as e:
            raise 

    def publish(self, geospace, d):
        d["header"]["version"] = "0.0.1"
        
        feed = FeedMessage()

        ParseDict(d, feed, True)

        raw = feed.SerializeToString()

        try:
            res = super().publish(Default.channel, geospace, raw)
        except MeshRPCException as e:
            raise 
    
    def get_channel(self):
        return Default.channel
    



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="mesh_atc",
    version="0.0.2",
    author="Abhishek Upperwal",
    author_email="mesh@soket.in",
    description="Flight data client for mesh-pravah",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pravahio",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires = [
        'mesh_rpc',
        'protobuf'
    ]
)


from .lib.atc_pb2 import Status

class Default:
    channel = "/FlightData"
    rpcURL = "127.0.0.1:5555"

class Status:
    SCHEDULED = Status.SCHEDULED
    DELAYED = Status.DELAYED
    CANCELLED = Status.CANCELLED
    ON_TIME = Status.ON_TIME
    GATE_OPEN = Status.GATE_OPEN
    FINAL_CALL = Status.FINAL_CALL
    GATE_CLOSED = Status.GATE_CLOSED
    DEPARTED = Status.DEPARTED
    IN_AIR = Status.IN_AIR
    LANDED = Status.LANDED
    ARRIVED = Status.ARRIVED   



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: atc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='atc.proto',
  package='atc',
  syntax='proto3',
  serialized_options=_b('\n\025io.pravah.transit.atc'),
  serialized_pb=_b('\n\tatc.proto\x12\x03\x61tc\"R\n\x0b\x46\x65\x65\x64Message\x12\x1f\n\x06header\x18\x01 \x01(\x0b\x32\x0f.atc.FeedHeader\x12\"\n\x08\x61irports\x18\x02 \x03(\x0b\x32\x10.atc.FeedAirport\"\x9e\x01\n\nFeedHeader\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x0eincrementality\x18\x02 \x01(\x0e\x32\x1e.atc.FeedHeader.Incrementality\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"4\n\x0eIncrementality\x12\x10\n\x0c\x46ULL_DATASET\x10\x00\x12\x10\n\x0c\x44IFFERENTIAL\x10\x01\"\\\n\x0b\x46\x65\x65\x64\x41irport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\tterminals\x18\x03 \x03(\x0b\x32\r.atc.Terminal\x12\x11\n\ttimestamp\x18\t \x01(\x04\"<\n\x08Terminal\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\rflightUpdates\x18\x02 \x03(\x0b\x32\x0b.atc.Flight\"\x85\x01\n\x06\x46light\x12\x1e\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x10.atc.AirportNode\x12\x1d\n\x03via\x18\x02 \x03(\x0b\x32\x10.atc.AirportNode\x12\x1c\n\x02to\x18\x03 \x01(\x0b\x32\x10.atc.AirportNode\x12\x1e\n\x04info\x18\x04 \x01(\x0b\x32\x10.atc.AirlineInfo\"5\n\x0b\x41irlineInfo\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xb8\x01\n\x0b\x41irportNode\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08terminal\x18\x02 \x01(\t\x12\x0c\n\x04gate\x18\x03 \x01(\t\x12\x1e\n\x0b\x61rrivalTime\x18\x04 \x01(\x0b\x32\t.atc.Time\x12 \n\rdepartureTime\x18\x05 \x01(\x0b\x32\t.atc.Time\x12\x1b\n\x06status\x18\x06 \x01(\x0b\x32\x0b.atc.Status\x12\x0c\n\x04name\x18\x64 \x01(\t\x12\x10\n\x08location\x18\x65 \x01(\t\")\n\x04Time\x12\x11\n\tscheduled\x18\x01 \x01(\x04\x12\x0e\n\x06\x61\x63tual\x18\x02 \x01(\x04\"\x80\x02\n\x06Status\x12.\n\x0c\x66lightStatus\x18\x01 \x01(\x0e\x32\x18.atc.Status.FlightStatus\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xb4\x01\n\x0c\x46lightStatus\x12\r\n\tSCHEDULED\x10\x00\x12\x0b\n\x07\x44\x45LAYED\x10\x01\x12\t\n\x05\x45\x41RLY\x10\x02\x12\r\n\tCANCELLED\x10\x03\x12\x0b\n\x07ON_TIME\x10\x04\x12\r\n\tGATE_OPEN\x10\x05\x12\x0e\n\nFINAL_CALL\x10\x06\x12\x0f\n\x0bGATE_CLOSED\x10\x07\x12\x0c\n\x08\x44\x45PARTED\x10\x08\x12\n\n\x06IN_AIR\x10\t\x12\n\n\x06LANDED\x10\n\x12\x0b\n\x07\x41RRIVED\x10\x0b\x42\x17\n\x15io.pravah.transit.atcb\x06proto3')
)



_FEEDHEADER_INCREMENTALITY = _descriptor.EnumDescriptor(
  name='Incrementality',
  full_name='atc.FeedHeader.Incrementality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FULL_DATASET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIFFERENTIAL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=209,
  serialized_end=261,
)
_sym_db.RegisterEnumDescriptor(_FEEDHEADER_INCREMENTALITY)

_STATUS_FLIGHTSTATUS = _descriptor.EnumDescriptor(
  name='FlightStatus',
  full_name='atc.Status.FlightStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELAYED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EARLY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON_TIME', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GATE_OPEN', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_CALL', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GATE_CLOSED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPARTED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_AIR', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANDED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARRIVED', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=917,
  serialized_end=1097,
)
_sym_db.RegisterEnumDescriptor(_STATUS_FLIGHTSTATUS)


_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='atc.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='atc.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='airports', full_name='atc.FeedMessage.airports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=100,
)


_FEEDHEADER = _descriptor.Descriptor(
  name='FeedHeader',
  full_name='atc.FeedHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='atc.FeedHeader.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incrementality', full_name='atc.FeedHeader.incrementality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='atc.FeedHeader.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDHEADER_INCREMENTALITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=261,
)


_FEEDAIRPORT = _descriptor.Descriptor(
  name='FeedAirport',
  full_name='atc.FeedAirport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='atc.FeedAirport.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='atc.FeedAirport.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='terminals', full_name='atc.FeedAirport.terminals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='atc.FeedAirport.timestamp', index=3,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=355,
)


_TERMINAL = _descriptor.Descriptor(
  name='Terminal',
  full_name='atc.Terminal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='atc.Terminal.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightUpdates', full_name='atc.Terminal.flightUpdates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=417,
)


_FLIGHT = _descriptor.Descriptor(
  name='Flight',
  full_name='atc.Flight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='atc.Flight.from', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='via', full_name='atc.Flight.via', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='atc.Flight.to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='atc.Flight.info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=553,
)


_AIRLINEINFO = _descriptor.Descriptor(
  name='AirlineInfo',
  full_name='atc.AirlineInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='atc.AirlineInfo.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='atc.AirlineInfo.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='atc.AirlineInfo.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=608,
)


_AIRPORTNODE = _descriptor.Descriptor(
  name='AirportNode',
  full_name='atc.AirportNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='atc.AirportNode.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='terminal', full_name='atc.AirportNode.terminal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gate', full_name='atc.AirportNode.gate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrivalTime', full_name='atc.AirportNode.arrivalTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='departureTime', full_name='atc.AirportNode.departureTime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='atc.AirportNode.status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='atc.AirportNode.name', index=6,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='atc.AirportNode.location', index=7,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=795,
)


_TIME = _descriptor.Descriptor(
  name='Time',
  full_name='atc.Time',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduled', full_name='atc.Time.scheduled', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actual', full_name='atc.Time.actual', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=838,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='atc.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flightStatus', full_name='atc.Status.flightStatus', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='atc.Status.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUS_FLIGHTSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=1097,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = _FEEDHEADER
_FEEDMESSAGE.fields_by_name['airports'].message_type = _FEEDAIRPORT
_FEEDHEADER.fields_by_name['incrementality'].enum_type = _FEEDHEADER_INCREMENTALITY
_FEEDHEADER_INCREMENTALITY.containing_type = _FEEDHEADER
_FEEDAIRPORT.fields_by_name['terminals'].message_type = _TERMINAL
_TERMINAL.fields_by_name['flightUpdates'].message_type = _FLIGHT
_FLIGHT.fields_by_name['from'].message_type = _AIRPORTNODE
_FLIGHT.fields_by_name['via'].message_type = _AIRPORTNODE
_FLIGHT.fields_by_name['to'].message_type = _AIRPORTNODE
_FLIGHT.fields_by_name['info'].message_type = _AIRLINEINFO
_AIRPORTNODE.fields_by_name['arrivalTime'].message_type = _TIME
_AIRPORTNODE.fields_by_name['departureTime'].message_type = _TIME
_AIRPORTNODE.fields_by_name['status'].message_type = _STATUS
_STATUS.fields_by_name['flightStatus'].enum_type = _STATUS_FLIGHTSTATUS
_STATUS_FLIGHTSTATUS.containing_type = _STATUS
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedHeader'] = _FEEDHEADER
DESCRIPTOR.message_types_by_name['FeedAirport'] = _FEEDAIRPORT
DESCRIPTOR.message_types_by_name['Terminal'] = _TERMINAL
DESCRIPTOR.message_types_by_name['Flight'] = _FLIGHT
DESCRIPTOR.message_types_by_name['AirlineInfo'] = _AIRLINEINFO
DESCRIPTOR.message_types_by_name['AirportNode'] = _AIRPORTNODE
DESCRIPTOR.message_types_by_name['Time'] = _TIME
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMESSAGE,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.FeedMessage)
  ))
_sym_db.RegisterMessage(FeedMessage)

FeedHeader = _reflection.GeneratedProtocolMessageType('FeedHeader', (_message.Message,), dict(
  DESCRIPTOR = _FEEDHEADER,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.FeedHeader)
  ))
_sym_db.RegisterMessage(FeedHeader)

FeedAirport = _reflection.GeneratedProtocolMessageType('FeedAirport', (_message.Message,), dict(
  DESCRIPTOR = _FEEDAIRPORT,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.FeedAirport)
  ))
_sym_db.RegisterMessage(FeedAirport)

Terminal = _reflection.GeneratedProtocolMessageType('Terminal', (_message.Message,), dict(
  DESCRIPTOR = _TERMINAL,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.Terminal)
  ))
_sym_db.RegisterMessage(Terminal)

Flight = _reflection.GeneratedProtocolMessageType('Flight', (_message.Message,), dict(
  DESCRIPTOR = _FLIGHT,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.Flight)
  ))
_sym_db.RegisterMessage(Flight)

AirlineInfo = _reflection.GeneratedProtocolMessageType('AirlineInfo', (_message.Message,), dict(
  DESCRIPTOR = _AIRLINEINFO,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.AirlineInfo)
  ))
_sym_db.RegisterMessage(AirlineInfo)

AirportNode = _reflection.GeneratedProtocolMessageType('AirportNode', (_message.Message,), dict(
  DESCRIPTOR = _AIRPORTNODE,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.AirportNode)
  ))
_sym_db.RegisterMessage(AirportNode)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), dict(
  DESCRIPTOR = _TIME,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.Time)
  ))
_sym_db.RegisterMessage(Time)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'atc_pb2'
  # @@protoc_insertion_point(class_scope:atc.Status)
  ))
_sym_db.RegisterMessage(Status)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
